pub struct VaultTransactionCreateData {
pub args: VaultTransactionCreateArgs,
}Expand description
Instruction.
Fields
args: VaultTransactionCreateArgsTrait Implementations
Sourceimpl BorshDeserialize for VaultTransactionCreate
impl BorshDeserialize for VaultTransactionCreate
fn deserialize_reader<R>(
reader: &mut R,
) -> Result<VaultTransactionCreate, Error>where
R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for VaultTransactionCreate
impl Discriminator for VaultTransactionCreate
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more