pub struct MultisigConfig<'info> {
pub multisig: AccountInfo<'info>,
pub config_authority: AccountInfo<'info>,
pub rent_payer: Option<AccountInfo<'info>>,
pub system_program: Option<AccountInfo<'info>>,
}Expand description
Generated CPI struct of the accounts for MultisigConfig.
Fields
multisig: AccountInfo<'info>Multisig config_authority that must authorize the configuration change.
rent_payer: Option<AccountInfo<'info>>The account that will be charged or credited in case the multisig account needs to reallocate space,
for example when adding a new member or a spending limit.
This is usually the same as config_authority, but can be a different account if needed.
system_program: Option<AccountInfo<'info>>We might need it in case reallocation is needed.