pub struct MultisigCreateV2<'info> {
pub program_config: AccountInfo<'info>,
pub treasury: AccountInfo<'info>,
pub multisig: AccountInfo<'info>,
pub create_key: AccountInfo<'info>,
pub creator: AccountInfo<'info>,
pub system_program: AccountInfo<'info>,
}Expand description
Generated CPI struct of the accounts for MultisigCreateV2.
Fields
program_config: AccountInfo<'info>Global program config account.
treasury: AccountInfo<'info>The treasury where the creation fee is transferred to.
multisig: AccountInfo<'info>create_key: AccountInfo<'info>An ephemeral signer that is used as a seed for the Multisig PDA. Must be a signer to prevent front-running attack by someone else but the original creator.
creator: AccountInfo<'info>The creator of the multisig.
system_program: AccountInfo<'info>Trait Implementations
Sourceimpl<'info> ToAccountInfos<'info> for MultisigCreateV2<'info>
impl<'info> ToAccountInfos<'info> for MultisigCreateV2<'info>
fn to_account_infos(&self) -> Vec<AccountInfo<'info>>
Sourceimpl<'info> ToAccountMetas for MultisigCreateV2<'info>
impl<'info> ToAccountMetas for MultisigCreateV2<'info>
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl<'info> !RefUnwindSafe for MultisigCreateV2<'info>
impl<'info> !Send for MultisigCreateV2<'info>
impl<'info> !Sync for MultisigCreateV2<'info>
impl<'info> !UnwindSafe for MultisigCreateV2<'info>
impl<'info> Freeze for MultisigCreateV2<'info>
impl<'info> Unpin for MultisigCreateV2<'info>
impl<'info> UnsafeUnpin for MultisigCreateV2<'info>