pub struct SpendingLimitUse<'info> {
pub multisig: AccountInfo<'info>,
pub member: AccountInfo<'info>,
pub spending_limit: AccountInfo<'info>,
pub vault: AccountInfo<'info>,
pub destination: AccountInfo<'info>,
pub system_program: Option<AccountInfo<'info>>,
pub mint: Option<AccountInfo<'info>>,
pub vault_token_account: Option<AccountInfo<'info>>,
pub destination_token_account: Option<AccountInfo<'info>>,
pub token_program: Option<AccountInfo<'info>>,
}Expand description
Generated CPI struct of the accounts for SpendingLimitUse.
Fields
multisig: AccountInfo<'info>The multisig account the spending_limit is for.
member: AccountInfo<'info>spending_limit: AccountInfo<'info>The SpendingLimit account to use.
vault: AccountInfo<'info>Multisig vault account to transfer tokens from.
destination: AccountInfo<'info>Destination account to transfer tokens to.
system_program: Option<AccountInfo<'info>>In case spending_limit.mint is SOL.
mint: Option<AccountInfo<'info>>The mint of the tokens to transfer in case spending_limit.mint is an SPL token.
vault_token_account: Option<AccountInfo<'info>>Multisig vault token account to transfer tokens from in case spending_limit.mint is an SPL token.
destination_token_account: Option<AccountInfo<'info>>Destination token account in case spending_limit.mint is an SPL token.
token_program: Option<AccountInfo<'info>>In case spending_limit.mint is an SPL token.