pub struct Proposal {
pub multisig: Pubkey,
pub transaction_index: u64,
pub status: ProposalStatus,
pub bump: u8,
pub approved: Vec<Pubkey>,
pub rejected: Vec<Pubkey>,
pub cancelled: Vec<Pubkey>,
}Expand description
Stores the data required for tracking the status of a multisig proposal.
Each Proposal has a 1:1 association with a transaction account, e.g. a VaultTransaction or a ConfigTransaction;
the latter can be executed only after the Proposal has been approved and its time lock is released.
Fields
multisig: PubkeyThe multisig this belongs to.
transaction_index: u64Index of the multisig transaction this proposal is associated with.
status: ProposalStatusThe status of the transaction.
bump: u8PDA bump.
approved: Vec<Pubkey>Keys that have approved/signed.
rejected: Vec<Pubkey>Keys that have rejected.
cancelled: Vec<Pubkey>Keys that have cancelled (Approved only).
Implementations
Sourceimpl Proposal
impl Proposal
pub fn size(members_len: usize) -> usize
Sourcepub fn approve(&mut self, member: Pubkey, threshold: usize) -> Result<(), Error>
pub fn approve(&mut self, member: Pubkey, threshold: usize) -> Result<(), Error>
Register an approval vote.
Sourcepub fn reject(&mut self, member: Pubkey, cutoff: usize) -> Result<(), Error>
pub fn reject(&mut self, member: Pubkey, cutoff: usize) -> Result<(), Error>
Register a rejection vote.
Sourcepub fn cancel(&mut self, member: Pubkey, threshold: usize) -> Result<(), Error>
pub fn cancel(&mut self, member: Pubkey, threshold: usize) -> Result<(), Error>
Registers a cancellation vote.
Sourcepub fn realloc_if_needed<'a>(
proposal: AccountInfo<'a>,
members_length: usize,
rent_payer: Option<AccountInfo<'a>>,
system_program: Option<AccountInfo<'a>>,
) -> Result<bool, Error>
pub fn realloc_if_needed<'a>( proposal: AccountInfo<'a>, members_length: usize, rent_payer: Option<AccountInfo<'a>>, system_program: Option<AccountInfo<'a>>, ) -> Result<bool, Error>
Check if the proposal account space needs to be reallocated to accommodate cancelled vec.
Proposal size is crated at creation, and thus may not accomodate enough space for all members to cancel if more are added or changed
Returns true if the account was reallocated.